# LitePipeline Helper

A distributed pipeline system, based on Python3, tornado, venv-pack, pyinstaller.

All code based on Python3, do not use Python2!

It still under development, so, maybe have some bugs or not stable enough!

See more details at https://github.com/fiefdx/LitePipeline

# Install
```bash
# install from pip
$ pip3 install -U litepipeline_helper
# or install from source code
$ cd ./litepipeline_helper
$ python3 ./setup.py install
```
